@@ -16,6 +16,7 @@ package commands
 import (
 	"encoding/base64"
 	"encoding/json"
+	"errors"
 	"fmt"
 	"os"
 	"os/exec"
@@ -45,8 +46,14 @@ const (
 	DOSecretOperatorAnnotation = "digitalocean.com/dosecret-identifier"
 
 	oauthTokenRevokeEndpoint = "https://cloud.digitalocean.com/v1/oauth/revoke"
+
+	// defaultRegistryAPITokenExpirySeconds is the default number of seconds before a registry API
+	// token expires. 2592000 is 30 days in seconds.
+	defaultRegistryAPITokenExpirySeconds = 2592000
 )
 
+var errExpiryTimeAndNeverExpire = errors.New("the generated registry API token cannot have both the expiry time and never-expire set")
+
 // Registry creates the registry command
 func Registry() *Command {
 	cmd := &Command{
@@ -55,6 +62,7 @@ func Registry() *Command {
 			Aliases: []string{"reg", "r"},
 			Short:   "Display commands for working with container registries",
 			Long:    "The subcommands of `doctl registry` create, manage, and allow access to your private container registry.",
+			GroupID: manageResourcesGroup,
 		},
 	}
 
@@ -83,9 +91,11 @@ func Registry() *Command {
 	cmdRegistryLogin := CmdBuilder(cmd, RunRegistryLogin, "login", "Log in Docker to a container registry",
 		loginRegDesc, Writer)
 	AddIntFlag(cmdRegistryLogin, doctl.ArgRegistryExpirySeconds, "", 0,
-		"The length of time the registry credentials will be valid for in seconds. By default, the credentials do not expire.")
+		"The length of time the registry credentials will be valid for in seconds. By default, the credentials expire after 30 days.")
 	AddBoolFlag(cmdRegistryLogin, doctl.ArgRegistryReadOnly, "", false,
 		"If true, the DigitalOcean API token generated by the login command will be read-only, causing any push operations to fail. By default, the API token is read-write.")
+	AddBoolFlag(cmdRegistryLogin, doctl.ArgRegistryNeverExpire, "", false,
+		"If true, the DigitalOcean API token generated by the login command will never expire. By default, this is false.")
 
 	logoutRegDesc := "This command logs Docker out of the private container registry, revoking access to it."
 	cmdRunRegistryLogout := CmdBuilder(cmd, RunRegistryLogout, "logout", "Log out Docker from a container registry",
@@ -381,23 +391,37 @@ func RunRegistryLogin(c *CmdConfig) error {
 	if err != nil {
 		return err
 	}
+	neverExpire, err := c.Doit.GetBool(c.NS, doctl.ArgRegistryNeverExpire)
+	if err != nil {
+		return err
+	}
+	if neverExpire && expirySeconds > 0 {
+		return errExpiryTimeAndNeverExpire
+	}
 	readOnly, err := c.Doit.GetBool(c.NS, doctl.ArgRegistryReadOnly)
 	if err != nil {
 		return err
 	}
 
 	regCredReq := godo.RegistryDockerCredentialsRequest{
-		ReadWrite: !readOnly,
+		ReadWrite:     !readOnly,
+		ExpirySeconds: godo.Int(defaultRegistryAPITokenExpirySeconds),
 	}
 	if expirySeconds != 0 {
 		regCredReq.ExpirySeconds = godo.Int(expirySeconds)
 	}
+	if neverExpire {
+		regCredReq.ExpirySeconds = nil
+	}
 
 	fmt.Printf("Logging Docker in to %s\n", c.Registry().Endpoint())
 	creds, err := c.Registry().DockerCredentials(&regCredReq)
 	if err != nil {
 		return err
 	}
+	if expirySeconds == 0 && !neverExpire {
+		notice("Login valid for 30 days. Use the --expiry-seconds flag to set a shorter expiration or --never-expire for no expiration.")
+	}
 
 	var dc dockerConfig
 	err = json.Unmarshal(creds.DockerConfigJSON, &dc)
